explorer_sidebar_ui: some menu items of the dashboard sidebar

View source: R/ui.R

explorer_sidebar_uiR Documentation

some menu items of the dashboard sidebar

Description

to generate some menu items for the dashboard, which can be integrated to other packages, such as 'fentouxungui/SeuratExplorerServer' from github.

Usage

explorer_sidebar_ui()

Value

return some menu items for the dashboard

Examples

explorer_sidebar_ui()


SeuratExplorer documentation built on Jan. 19, 2026, 9:07 a.m.